@@ -167,6 +167,7 @@ AJS.List = AJS.Control.extend({
         if (!AJS.dim.dim) {
             $target.scrollIntoView({
                 duration: 100,
+                marginBottom: 50,
                 callback: AJS.$.proxy(this.motionDetector, "wait")
             });
         } else {
@@ -310,51 +311,14 @@ AJS.List = AJS.Control.extend({
     _generateOption: function (item, query) {
         var replacementText;
 
-        if (query) {
-
-            var regexEscapedQuery = RegExp.escape(query);
-            var regex = new RegExp(AJS.format(this.options.matchingStrategy, regexEscapedQuery), "i");
-
-            item.labelSuffix("");
-
-            if (!regex.test(item.label())) {
-
-                // if we didn't match on the label, try to match on keywords
-                // for each keyword that contains the query, add it to the item's suffix string
-                // otherwise return null if we don't match on the label or on any keywords
-
-                var matchedKeywords = "";
-
-                if (item.keywords()) {
-                    var keywordString = "" + item.keywords();
-                    var keywords = keywordString.split(",");
-                    var keywordsRegex = new RegExp(AJS.format(".*{0}.*", regexEscapedQuery), "i");
-
-                    for (var i = 0; i < keywords.length; i++) {
-                        var keyword = keywords[i];
-                        if (keywordsRegex.test(keyword)) {
-                            if (matchedKeywords != "") {
-                                matchedKeywords += ", ";
-                            }
-                            matchedKeywords += keyword;
-                        }
-                    }
-                }
-
-                if (matchedKeywords != "") {
-                    item.labelSuffix(" " + matchedKeywords);
-                } else {
-                    return null;
-                }
-            } else {
-                replacementText = item.label().replace(regex, function (_, prefix, match, suffix) {
-                    return AJS.$("<div>")
-                        .append(AJS.$("<span>").text(prefix))
-                        .append(AJS.$("<em>").text(match))
-                        .append(AJS.$("<span>").text(suffix))
-                        .html();
-                });
-            }
+        if (query && item.labelSuffix() === "") {
+            replacementText = item.label().replace(this.regex, function (_, prefix, match, suffix) {
+                return AJS.$("<div>")
+                    .append(AJS.$("<span>").text(prefix))
+                    .append(AJS.$("<em>").text(match))
+                    .append(AJS.$("<span>").text(suffix))
+                    .html();
+            });
         }
 
         if (this.exactMatchIndex < 0) {
@@ -371,19 +335,86 @@ AJS.List = AJS.Control.extend({
         return this._render("suggestion", item, replacementText);
     },
 
-    _generateUngroupedOptions: function (options, query) {
-        var hasSuggestion = false,
-            instance = this,
-            $container = this._render("ungroupedSuggestions");
+    _filterUngroupedOptions: function(options) {
+        var instance = this,
+            filtered = [],
+            keywordsRegex = (this.regexEscapedQuery) ? new RegExp(AJS.format(".*{0}.*", this.regexEscapedQuery), "i") : null;
 
-        AJS.$.each(options, function (_, option) {
-            var $suggestion = instance._generateOption(option, query);
-            if ($suggestion) {
-                hasSuggestion = true;
-                $container.append($suggestion);
+        AJS.$.each(options, function(i, item) {
+                item.labelSuffix("");
+
+                if (instance.regex && !instance.regex.test(item.label())) {
+
+                    // if we didn't match on the label, try to match on keywords
+                    // for each keyword that contains the query, add it to the item's suffix string
+                    // otherwise return null if we don't match on the label or on any keywords
+
+                    var matchedKeywords = "";
+
+                    if (item.keywords()) {
+                        var keywordString = "" + item.keywords(),
+                            keywords = keywordString.split(",");
+
+                        for (var i = 0; i < keywords.length; i++) {
+                            var keyword = keywords[i];
+                            if (keywordsRegex.test(keyword)) {
+                                if (matchedKeywords != "") {
+                                    matchedKeywords += ", ";
+                                }
+                                matchedKeywords += keyword;
+                            }
+                        }
+                    }
+
+                    if (matchedKeywords != "") {
+                        item.labelSuffix(" " + matchedKeywords);
+                        filtered.push(item);
+                    }
+                } else {
+                    filtered.push(item);
+                }
+        });
+
+        return filtered;
+    },
+
+    _setRegexFromQuery: function(query) {
+        this.regexEscapedQuery = (query) ? RegExp.escape(query) : null;
+        this.regex = (query) ? new RegExp(AJS.format(this.options.matchingStrategy, this.regexEscapedQuery), "i") : null;
+    },
+
+    _addOptionsToContainer: function(options, $container, query) {
+        var instance = this,
+            maxInlineResultsDisplayed = this.options.maxInlineResultsDisplayed,
+            hasSuggestion = false;
+        AJS.$.each(options, function(i, option) {
+            if (!maxInlineResultsDisplayed || i < maxInlineResultsDisplayed || !query) {
+                var $suggestion = instance._generateOption(option, query);
+                if ($suggestion) {
+                    hasSuggestion = true;
+                    $container.append($suggestion);
+                }
+            } else {
+                $container.append(instance._render("tooManySuggestions", options.length - i));
+                return false;
             }
         });
 
+        return hasSuggestion;
+    },
+
+    _generateUngroupedOptions: function (options, query) {
+        var instance = this,
+            $container = this._render("ungroupedSuggestions");
+
+        this._setRegexFromQuery(query);
+
+        if (query) {
+            options = this._filterUngroupedOptions(options);
+        }
+
+        var hasSuggestion = this._addOptionsToContainer(options, $container, query);
+
         if (hasSuggestion) {
             return $container;
         }
@@ -392,18 +423,16 @@ AJS.List = AJS.Control.extend({
     _generateOptGroup: function (groupDescriptor, query) {
 
         var res = AJS.$(),
-            hasSuggestion,
-            instance = this,
-            optContainer = this._render("suggestionGroup", groupDescriptor);
+            optContainer = this._render("suggestionGroup", groupDescriptor),
+            options = groupDescriptor.items();
 
+        this._setRegexFromQuery(query);
 
-        AJS.$.each(groupDescriptor.items(), function (i, option) {
-            var suggestion = instance._generateOption(option, query);
-            if (suggestion) {
-                hasSuggestion = true,
-                optContainer.append(suggestion);
-            }
-        });
+        if (query) {
+            options = this._filterUngroupedOptions(options);
+        }
+
+        var hasSuggestion = this._addOptionsToContainer(options, optContainer, query);
 
         if (!hasSuggestion) {
             return;
@@ -415,7 +444,6 @@ AJS.List = AJS.Control.extend({
 
         res = res.add(optContainer);
 
-
         return res;
     },
 
@@ -471,7 +499,10 @@ AJS.List = AJS.Control.extend({
             return listElem;
         },
         noSuggestion: function () {
-            return AJS.$("<div class='no-suggestions'><span style='font-style:oblique'>" + AJS.I18n.getText("common.concepts.no.matches") + "</span></div>");
+            return AJS.$("<li class='no-suggestions'>" + AJS.I18n.getText("common.concepts.no.matches") + "</li>");
+        },
+        tooManySuggestions: function(suggestionCount) {
+            return AJS.$("<li class='no-suggestions'>" + AJS.I18n.getText("common.concepts.too.many.matches", suggestionCount) + "</li>");
         },
         ungroupedSuggestions: function () {
             return AJS.$('<ul>');
