@@ -159,7 +159,11 @@ AJS.QueryableDropdownSelect = AJS.Control.extend({
             },
             // keyInputPeriod: expected milliseconds between consecutive keystrokes
             // If this user types faster than this, no requests will be issued until they slow down.
-            keyInputPeriod: 75
+            keyInputPeriod: 75,
+            // localListLiveUpdateLimit: Won't search for new options if there are more options than this value
+            localListLiveUpdateLimit: 25,
+            // Only search for new options locally after this delay.
+            localListLiveUpdateDelay: 150
         };
     },
 
@@ -290,7 +294,23 @@ AJS.QueryableDropdownSelect = AJS.Control.extend({
 
         var instance = this;
 
-        this.$field.preventBlurFromElements(instance.dropdownController.$layer, instance.$container);
+        // Shinanignas to ensure that when we scroll the window it does not hide our suggestions - ie7 and below
+        if (jQuery.browser.msie && jQuery.browser.version < 8) {
+            this.$field.bind("beforedeactivate", function (e) {
+                if (e.toElement === document.documentElement) {
+                    var blurEvents = instance.$field.data("events").blur;  // store reference to all blur events
+                    delete instance.$field.data("events").blur; // remove all blur events now
+                    instance.$field.one("blur", function () {
+                        instance.$field.focus();
+                        // need to use timeout otherwise all event handlers will still be fired, as they are referenced in the
+                        // same array as the one we just added.
+                        window.setTimeout(function (    ) {
+                            instance.$field.data("events").blur = blurEvents;
+                        }, 0);
+                   });
+                }
+            });
+        }
 
         this._assignEvents("ignoreBlurElement", this.dropdownController.$layer);
 
@@ -470,7 +490,18 @@ AJS.QueryableDropdownSelect = AJS.Control.extend({
                 this.$dropDownIcon.removeClass("noloading");
                 this._requestThenResetSuggestions(ignoreBuffer);
             } else {
-                this._setSuggestions(this.model.getUnSelectedDescriptors());
+                var descriptors = this.model.getUnSelectedDescriptors(),
+                    instance = this;
+                if (this.inlineBufferTimeout) {
+                    clearTimeout(this.inlineBufferTimeout);
+                }
+                if (descriptors.length >= this.options.localListLiveUpdateLimit) {
+                    this.inlineBufferTimeout = setTimeout(function() {
+                        instance._setSuggestions(descriptors);
+                    }, this.options.localListLiveUpdateDelay);
+                } else {
+                    this._setSuggestions(descriptors);
+                }
             }
         } else {
             this._setSuggestions();
@@ -512,7 +543,7 @@ AJS.QueryableDropdownSelect = AJS.Control.extend({
         if (!this.suggestionsVisible) {
             return;
         }
-
+        clearTimeout(this.inlineBufferTimeout);
         this._rejectPendingRequests();
         this.suggestionsVisible = false;
         this.$dropDownIcon.addClass("noloading");
@@ -613,19 +644,21 @@ AJS.QueryableDropdownSelect = AJS.Control.extend({
 
         ignoreBlurElement: {
             mousedown: function (e) {
+
+                var instance = this;
+
                 // Preventing the default action of "mousedown" events stops the
                 // activeElement losing focus in all non-IE. We need to use a funky
                 // workaround for IE which allows the field to lose focus briefly
                 // so that UI controls like scrollbars are still interactive.
                 if (jQuery.browser.msie) {
-                    var instance = this;
                     this.ignoreBlurEvent = true;
-                    setTimeout(function() {
+                    jQuery(e.target).one("focus", function () {
                         instance.$field.focus();
                         instance.ignoreBlurEvent = false;
-                    }, 0);
+                    });
                 } else {
-                    e.preventDefault();
+                    e.preventDefault()
                 }
             }
         }
