@@ -78,8 +78,6 @@ AJS.ACTIVE_CLASS = "active";
 AJS.BOX_SHADOW_CLASS = "box-shadow";
 AJS.LOADING_CLASS = "loading";
 AJS.INTELLIGENT_GUESS = "Intelligent Guess";
-AJS.DIRTY_FORM_VALUE = "AJS_DirtyForms_cleanValue";
-AJS.DIRTY_FORM_EXEMPT = ".ajs-dirty-warning-exempt,[name=atl_token]";
 
 (function() {
     var SPECIAL_CHARS = /[.*+?|^$()[\]{\\]/g;
@@ -161,23 +159,14 @@ jQuery.aop.after({target: jQuery, method: "append"}, function (elem) {
 });
 
 /**
- * Returns true if we are running under Selenium.  Selenium can introduce Heisenbugs so that
- * we need to take slightly different code paths for it.  Please try to minimise these as much as
- * humanly possible.
+ * Determine whether Selenium is running.
+ *
+ * Note: This does not detect WebDriver. Please use very sparingly!
+ *
+ * @return {boolean}
  */
 AJS.isSelenium = function () {
-    var detectOn = function(obj)
-    {
-        for (var propName in obj)
-        {
-            if (propName.indexOf('selenium') != -1)
-            {
-                return true;
-            }
-        }
-        return false;
-    };
-    return detectOn(window.location) || detectOn(window);
+    return window.name.toLowerCase().indexOf("selenium") >= 0;
 };
 
 /**
