@@ -4,7 +4,8 @@
         new AJS.MultiSelect({
            element: $selectField,
            itemAttrDisplayed: "label",
-           errorMessage: AJS.I18n.getText("jira.ajax.autocomplete.components.error")
+           errorMessage: AJS.I18n.getText("jira.ajax.autocomplete.components.error"),
+           maxInlineResultsDisplayed: 15
         });
     }
 
