@@ -3,7 +3,8 @@
         new AJS.MultiSelect({
            element: $selectField,
            itemAttrDisplayed: "label",
-           errorMessage: AJS.I18n.getText("jira.ajax.autocomplete.versions.error")
+           errorMessage: AJS.I18n.getText("jira.ajax.autocomplete.versions.error"),
+           maxInlineResultsDisplayed: 15
         });
     }
 
