@@ -6,7 +6,7 @@ JIRA.Share = {
 };
 
 /** Preserve legacy namespace
-    @deprecated atlassian.jira.share */
+ @deprecated atlassian.jira.share */
 AJS.namespace("atlassian.jira.share", null, JIRA.Share);
 
 /**
@@ -128,8 +128,10 @@ JIRA.Share.EditSharesController.prototype =
         for (shareTypeName in this.shareTypes)
         {
             shareType = this.shareTypes[shareTypeName];
-            jQuery("#share_add_" + shareType.type).click((function(shareTypeRef){
-                return function(e) {
+            jQuery("#share_add_" + shareType.type).click((function(shareTypeRef)
+            {
+                return function(e)
+                {
                     that.addShareCallback(e, shareTypeRef);
                 }
             })(shareType));
@@ -190,12 +192,13 @@ JIRA.Share.EditSharesController.prototype =
                 busy.parentNode.removeChild(busy);
             }
         }
-        
+
         this.shareDiv.style.display = '';
 
         //register the "ShareType" selection change listener.
 
-        jQuery("#share_type_selector").change(function(e){
+        jQuery("#share_type_selector").change(function(e)
+        {
             that.selectShareTypeCallback(e);
         });
 
@@ -212,7 +215,8 @@ JIRA.Share.EditSharesController.prototype =
         // Add the warning for dirty content
         if (this.submitButtonId)
         {
-            jQuery("#" + this.submitButtonId).click(function(e){
+            jQuery("#" + this.submitButtonId).click(function(e)
+            {
                 that.saveCallback(e);
             });
 
@@ -283,7 +287,7 @@ JIRA.Share.EditSharesController.prototype =
 
         newDiv.className = "shareItem"
         newDiv.id = "share_div_" + newCount;
-        
+
         //create the div that will render the share.
         var shareDiv = document.createElement("DIV");
         shareDiv.id = "share_div_" + newCount + "_inner";
@@ -302,8 +306,9 @@ JIRA.Share.EditSharesController.prototype =
         if (newTrash)
         {
 
-            jQuery(newTrash).click(function(e){
-                that.removeCallback(e,newCount)
+            jQuery(newTrash).click(function(e)
+            {
+                that.removeCallback(e, newCount)
             });
 
             shareDiv.appendChild(newTrash);
@@ -491,14 +496,19 @@ JIRA.Share.EditSharesController.prototype =
         }
     },
 
-    setWarning : function(warning) {
+    setWarning : function(warning)
+    {
 
         var warningDiv = document.getElementById("share_warning");
-        if (warningDiv) {
-            if (warning.length > 0) {
+        if (warningDiv)
+        {
+            if (warning.length > 0)
+            {
                 warningDiv.className = "filter-share-warning aui-message warning";
                 warningDiv.innerHTML = warning;
-            } else {
+            }
+            else
+            {
                 warningDiv.className = "";
                 warningDiv.innerHTML = "";
             }
@@ -553,10 +563,12 @@ JIRA.Share.EditSharesController.prototype =
             }
 
             // testing for "fading" flag in classname, prevents multiple tweens being initiated
-            if (!jQuery(div).hasClass("fading")) {
+            if (!jQuery(div).hasClass("fading"))
+            {
                 jQuery(div).addClass("fading");
-                jQuery(div).css({backgroundColor: "#FFCCCC"}).animate({backgroundColor: "#FFFFFF"}, 2000, function(){
-                   jQuery(div).removeClass("fading"); 
+                jQuery(div).css({backgroundColor: "#FFCCCC"}).animate({backgroundColor: "#FFFFFF"}, 2000, function()
+                {
+                    jQuery(div).removeClass("fading");
                 });
             }
         }
@@ -572,7 +584,7 @@ JIRA.Share.EditSharesController.prototype =
         else
         {
             return null;
-        } 
+        }
     }
 };
 
@@ -668,7 +680,8 @@ JIRA.Share.SelectSingleShareTypeController.prototype =
             this.setDescription(shareType.getDisplayDescriptionFromUI());
 
 
-            jQuery(selectList).change(function(e){
+            jQuery(selectList).change(function(e)
+            {
                 that.selectShareTypeCallback(e);
             });
 
@@ -756,13 +769,18 @@ JIRA.Share.SelectSingleShareTypeController.prototype =
         }
     },
 
-    setWarning : function(warning) {
+    setWarning : function(warning)
+    {
         var warningDiv = document.getElementById("share_warning");
-        if (warningDiv) {
-            if (warning.length > 0) {
+        if (warningDiv)
+        {
+            if (warning.length > 0)
+            {
                 warningDiv.className = "aui-message warning";
                 warningDiv.innerHTML = warning;
-            } else {
+            }
+            else
+            {
                 warningDiv.className = "";
                 warningDiv.innerHTML = "";
             }
@@ -817,7 +835,8 @@ JIRA.Share.GlobalShare.prototype =
         var inner = JIRA.Share.i18n.getMessage("share_global_display");
         return new JIRA.Share.Display(inner, this.getDisplayDescriptionFromUI(), this.singleton, newPermission);
     },
-    getDisplayWarning : function() {
+    getDisplayWarning : function()
+    {
         return atlassian.jira.share.i18n.getMessage("share_global_warning");
     }
 };
@@ -847,7 +866,8 @@ JIRA.Share.GroupShare.prototype =
         if (this.groupSelect)
         {
 
-            jQuery(this.groupSelect).change(function(e){
+            jQuery(this.groupSelect).change(function(e)
+            {
                 that.groupChangeCallback(e);
             });
 
@@ -861,7 +881,9 @@ JIRA.Share.GroupShare.prototype =
     getDisplayFromUI : function()
     {
         if (!this.groupSelect)
+        {
             return;
+        }
 
         var value = this.groupSelect.options[this.groupSelect.selectedIndex].value;
         var newPermission = new JIRA.Share.SharePermission(this.type, value, null);
@@ -875,7 +897,9 @@ JIRA.Share.GroupShare.prototype =
     getDisplayDescriptionFromUI : function()
     {
         if (!this.groupSelect)
+        {
             return;
+        }
 
         var group = this.groupSelect.options[this.groupSelect.selectedIndex].value;
         return this.getDescriptionString(group, false);
@@ -954,7 +978,8 @@ JIRA.Share.GroupShare.prototype =
         }
     },
 
-    getDisplayWarning : function() {
+    getDisplayWarning : function()
+    {
         return "";
     }
 };
@@ -984,7 +1009,9 @@ JIRA.Share.ProjectShare.prototype =
         this.roleSelectGroup = document.getElementById("projectShare-role-group");
 
         if (!this.roleSelect || !this.projectSelect || !this.roleSelectGroup)
+        {
             return;
+        }
 
         var option, i;
 
@@ -1006,11 +1033,13 @@ JIRA.Share.ProjectShare.prototype =
         this.setRoles();
 
 
-        jQuery(this.projectSelect).change(function(e){
+        jQuery(this.projectSelect).change(function(e)
+        {
             that.changeCallbackForProject(e);
         });
 
-         jQuery(this.roleSelect).change(function(e){
+        jQuery(this.roleSelect).change(function(e)
+        {
             that.updateDescription(e);
         });
 
@@ -1023,7 +1052,9 @@ JIRA.Share.ProjectShare.prototype =
     getDisplayFromUI : function()
     {
         if (!this.projectSelect || !this.roleSelect)
+        {
             return;
+        }
 
         var selectedProjectOption = this.projectSelect.options[this.projectSelect.selectedIndex];
         var projectValue = selectedProjectOption.value;
@@ -1057,7 +1088,9 @@ JIRA.Share.ProjectShare.prototype =
     getDisplayDescriptionFromUI : function()
     {
         if (!this.projectSelect || !this.roleSelect)
+        {
             return;
+        }
 
         var selectedProjectOption = this.projectSelect.options[this.projectSelect.selectedIndex];
         var projectDisplay = selectedProjectOption.text;
@@ -1134,7 +1167,7 @@ JIRA.Share.ProjectShare.prototype =
         }
         else
         {
-            
+
             projectName = this.getProject(permission.param1);
             inner = JIRA.Share.i18n.getMessage("share_project_display_all");
             inner = JIRA.Share.i18n.formatMessage(inner, projectName);
@@ -1145,7 +1178,8 @@ JIRA.Share.ProjectShare.prototype =
         return new JIRA.Share.Display(inner, description, this.singleton, newPermission);
     },
 
-    getDisplayWarning : function() {
+    getDisplayWarning : function()
+    {
         return "";
     },
     /**
@@ -1172,7 +1206,9 @@ JIRA.Share.ProjectShare.prototype =
     setProject : function(selectedProjectId)
     {
         if (!this.projectSelect)
+        {
             return;
+        }
 
         var options = this.projectSelect.options;
         for (var i = 0; i < options.length; i++)
@@ -1191,7 +1227,9 @@ JIRA.Share.ProjectShare.prototype =
     setRoles: function(selectedRoleId)
     {
         if (!this.projectSelect || !this.roleSelect || !this.roleSelectGroup)
+        {
             return;
+        }
 
         var option = this.projectSelect.options[this.projectSelect.selectedIndex];
         var roles = option.getAttribute("roles");
@@ -1338,8 +1376,14 @@ JIRA.Share.Display = function(display, description, singleton, permission)
 JIRA.Share.SharePermission = function(type, param1, param2)
 {
     this.type = type;
-    if (param1) this.param1 = param1;
-    if (param2) this.param2 = param2;
+    if (param1)
+    {
+        this.param1 = param1;
+    }
+    if (param2)
+    {
+        this.param2 = param2;
+    }
 };
 
 /**
@@ -1350,8 +1394,8 @@ JIRA.Share.SharePermission = function(type, param1, param2)
 JIRA.Share.SharePermission.prototype.equals = function (otherPermission)
 {
     return this.type === otherPermission.type &&
-           this.param1 === otherPermission.param1 &&
-           this.param2 === otherPermission.param2;
+            this.param1 === otherPermission.param1 &&
+            this.param2 === otherPermission.param2;
 };
 
 /**
@@ -1364,7 +1408,8 @@ JIRA.Share.registerEditShareTypes = function(submitButtonId)
     editController.registerShareType(new JIRA.Share.GroupShare());
     editController.registerShareType(new JIRA.Share.ProjectShare());
 
-    jQuery(document).ready(function(){
+    jQuery(document).ready(function()
+    {
         editController.initialise();
     });
 };
@@ -1379,7 +1424,22 @@ JIRA.Share.registerSelectShareTypes = function()
     selectController.registerShareType(new JIRA.Share.GroupShare());
     selectController.registerShareType(new JIRA.Share.ProjectShare());
 
-    jQuery(document).ready(function(){
+    jQuery(document).ready(function()
+    {
         selectController.initialise();
     });
 };
+
+/**
+ * Called to bind the operations cog drop downs to the markup
+ */
+JIRA.Share.bindOperationDropDowns = function()
+{
+    var $container = AJS.$("#main-content");
+
+    AJS.Dropdown.create({
+        trigger: $container.find(".aui-dd-link"),
+        content: $container.find(".aui-list"),
+        alignment: AJS.RIGHT
+    });
+}
