@@ -105,11 +105,6 @@ jQuery(function (){
         }).openWindow();
     };
 
-    var resetCommentFormDirtyState = function() {
-        var $commentForm = AJS.$("form#issue-comment-add");
-        $commentForm.data(AJS.DIRTY_FORM_VALUE, $commentForm.find(":input[name!=atl_token]").serialize());
-    };
-
     /**
      * Cancels a comment. This means clearing the text area, resetting the
      * dirty state for the closes form, and collapsing the comment box.
@@ -131,8 +126,6 @@ jQuery(function (){
 
         // JRADEV-3411: disable preview if necessary so the comment gets cleared properly
         AJS.$('#comment-preview_link.selected').click();
-        
-        resetCommentFormDirtyState();
     };
     
     jQuery(document).bind(JIRA.Keyboard.SpecialKey.eventType(), function (e) {
@@ -140,7 +133,6 @@ jQuery(function (){
             if(jQuery("#comment-issue.active").length > 0) {
                 //this means we're closing the stalker bar comment.  Reset it's dirty
                 //form state since this is effectively like closing a dialog!
-                resetCommentFormDirtyState();
                 jQuery("#comment-issue.active").click();
             }
         }
