@@ -1137,7 +1137,7 @@ Calendar.prototype._init = function (firstDayOfWeek, date) {
             if (month == 0 && i == 0 && Date.useISO8601WeekNumbers == false) { // Jan and first week in row
                 monthStartDate = new Date(year,month,1);
             }
-            cell.innerHTML = monthStartDate.getWeekNumber();
+            cell.innerHTML = monthStartDate.getWeekNumber(this.firstDayOfWeek);
             cell = cell.nextSibling;
 		}
 		row.className = "daysrow";
@@ -1789,49 +1789,106 @@ Date.prototype.getDayOfYear = function() {
 };
 
 /** Returns the number of the week in year, as defined in ISO 8601. */
-Date.prototype.getWeekNumber = function() {
+Date.prototype.getWeekNumber = function(startOfWeek) {
     if (Date.useISO8601WeekNumbers) {
-        var d = new Date(this.getFullYear(), this.getMonth(), this.getDate(), 0, 0, 0);
-        var DoW = d.getDay();
-        d.setDate(d.getDate() - (DoW + 6) % 7 + 3); // Nearest Thu
-        var ms = d.valueOf(); // GMT
-        d.setMonth(0);
-        d.setDate(4); // Thu in Week 1
-        return Math.round((ms - d.valueOf()) / (7 * 864e5)) + 1;
+        return this.getISO8601WeekNumber();
     } else {
-        return this._getWeekNumberStandard();
+        return this.getSimpleWeekNumber(startOfWeek);
     }
 };
 
+/* Algorithm taken from: http://www.staff.science.uu.nl/~gent0113/calendar/isocalendar.htm
+ */
+Date.prototype.getISO8601WeekNumber = function() {
+    function gregdaynumber(year, month, day)
+    {
+        // computes the day number since 0 January 0 CE (Gregorian)
 
-/* Returns the number of the week in the year using Jan 01 as the first week */
-Date.prototype._getWeekNumberStandard = function() {
-    var MS_IN_A_DAY = 1000*60*60*24;
-    var date = this;
-	var calendarYear = date.getFullYear();
-	var weekNum = -1;
+        y = year;
+        m = month;
+        if (month < 3)
+        {
+            y = y - 1;
+        }
+        if (month < 3)
+        {
+            m = m + 12;
+        }
+        return Math.floor(365.25 * y) - Math.floor(y / 100) + Math.floor(y / 400) + Math.floor(30.6 * (m + 1)) + day - 62;
+    }
 
-	var jan1 = new Date(calendarYear,0,1);
-	var jan1DayOfWeek = jan1.getDay();
+    function isocalendar1(date)
+    {
 
+        // computes the ISO calendar date from the current Gregorian date
+        year = date.getFullYear();
+        month = date.getMonth(); // 0=January, 1=February, etc.
+        day = date.getDate();
+        wday = date.getDay();
 
-	// Find the number of days the date is away from the calendar year start
-	var dayOffset = Math.ceil((date.getTime()-jan1.getTime()) / MS_IN_A_DAY);
-	if (dayOffset < 0 && dayOffset >= (-1 * jan1DayOfWeek)) {
-		weekNum = 1;
-	} else {
-		weekNum = 1;
-        // copy jan 1 date
-	    var testDate = new Date(jan1.getTime());
-        testDate.setHours(0,0,0,0);
-        while (testDate.getTime() < date.getTime() && testDate.getFullYear() == calendarYear) {
-			weekNum += 1;
-			// add a week
-			testDate.setDate(testDate.getDate() + 7);
-		}
-	}
-	return weekNum;
-};
+        weekday = ((wday + 6) % 7) + 1; // weekdays will be numbered 1 to 7
+
+        isoyear = year;
+
+        d0 = gregdaynumber(year, 1, 0);
+        weekday0 = ((d0 + 4) % 7) + 1;
+
+        d = gregdaynumber(year, month + 1, day);
+        isoweeknr = Math.floor((d - d0 + weekday0 + 6) / 7) - Math.floor((weekday0 + 3) / 7);
+
+        // check whether the last few days of December belong to the next year's ISO week
+
+        if ((month == 11) && ((day - weekday) > 27))
+        {
+            isoweeknr = 1;
+            isoyear = isoyear + 1;
+        }
+
+        // check whether the first few days of January belong to the previous year's ISO week
+        if ((month == 0) && ((weekday - day) > 3))
+        {
+            d0 = gregdaynumber(year - 1, 1, 0);
+            weekday0 = ((d0 + 4) % 7) + 1;
+            isoweeknr = Math.floor((d - d0 + weekday0 + 6) / 7) - Math.floor((weekday0 + 3) / 7);
+            isoyear = isoyear - 1;
+        }
+
+        return isoweeknr;
+    }
+
+    return isocalendar1(this);
+}
+
+/* Algorithm taken from: http://www.merlyn.demon.co.uk/weekcalc.htm#NIP
+   Blame them for the shit variable and function names. Seriously, WTF?
+   This is "Type 1" with a Sun-Sat row.
+
+   Using the simple week counting you need to know
+   the start of week so you can do the calculations properly.
+
+   If you don't specify a startOfWeek then Sunday is used.
+*/
+
+Date.prototype.getSimpleWeekNumber = function(startOfWeek)
+{
+    function OddWkNo1(D, d1, d2)
+    {
+        var Yr = D.getFullYear(), Jan1 = new Date(Yr, 0, 1), Q;
+        Q = Math.round((D - Jan1) / 86400000);
+        if (d1 != null)
+        {
+            Q -= (7 + d1 - Jan1.getDay()) % 7;
+        }
+        if (d2 != null)
+        {
+            Q += d2;
+        }
+        return [Yr, 1 + Q / 7 | 0, 1 + (7 + Q) % 7];
+    }
+
+    return OddWkNo1(this, startOfWeek ? startOfWeek : 6, 6)[1];
+//    return OddWkNo1(this, 6, 6)[1];
+}
 
 /** Checks date and time equality */
 Date.prototype.equalsTo = function(date) {
